﻿Imports XCM
Imports XSP
Imports System.IO
Imports XSP.clsExcelFunc
Imports System.Runtime.ConstrainedExecution
Imports System.Collections.Specialized
Imports System.Windows.Forms

''' ---------------------------------------------
''' <summary>
''' 統計_統計表選択（配列情報及びEXCEL出力支援クラス）
''' </summary>
''' <remarks>
''' Copyright 2010 FUJITSU SHIKOKU SYSTEMS LIMITED All rights reserved.<BR/>
''' FUJITSU SHIKOKU SYSTEMS LIMITED CONFIDENTIAL<BR/>
''' </remarks>
''' ---------------------------------------------
Public NotInheritable Class clsLST010F010

#Region "解放処理"
	'確実な解放処理を実行するために指定
	Inherits CriticalFinalizerObject
	'解放処理を実装する為に指定
	Implements IDisposable

	''' ---------------------------------------------
	''' <summary>
	''' Dispose（解放処理）※外からはよばない
	''' </summary>
	''' <param name="disposing"></param>
	''' <remarks>
	''' 2010/10/07 新規作成　CS)松本<BR/>
	''' </remarks>
	''' ---------------------------------------------
	Protected Overloads Sub Dispose(ByVal disposing As Boolean)
		If disposing Then
			'ここで変数のクリアを行う

			datHspName = Nothing

			cPutTate = Nothing
			pPrmShtData = Nothing
		End If
	End Sub

	''' ---------------------------------------------
	''' <summary>
	''' Finalize（解放処理）
	''' </summary>
	''' <remarks>
	''' 2010/10/07 新規作成　CS)松本<BR/>
	''' </remarks>
	''' ---------------------------------------------
	Public Overloads Sub Dispose() Implements IDisposable.Dispose
		Dispose(True)
		MyBase.Finalize()
		GC.SuppressFinalize(Me)
	End Sub

	''' ---------------------------------------------
	''' <summary>
	''' Finalize（解放処理）※外からはよばない
	''' </summary>
	''' <remarks>
	''' 2010/10/07 新規作成　CS)松本<BR/>
	''' </remarks>
	''' ---------------------------------------------
	Protected Overrides Sub Finalize()
		Dispose(False)
		MyBase.Finalize()
	End Sub
#End Region

#Region "変数"

	' 縦軸・横軸検索用変数
	Private pFindKey_Tate As String
	Private pFindKey_Yoko1 As String
	Private pFindKey_Yoko2 As String

	''' ---------------------------------------------
	''' <summary>
	''' 縦軸情報
	''' </summary>
	''' <remarks>
	''' 2010/10/07 新規作成　CS)松本<BR/>
	''' </remarks>
	''' ---------------------------------------------
	Public Class clsTate
		Public TateKey As String
		Public TateName As String
		Public LstYokoData As List(Of clsYoko)

		''' ---------------------------------------------
		''' <summary>
		''' コンストラクタ
		''' </summary>
		''' <param name="pTateKey">縦軸キー</param>
		''' <param name="pTateName">縦軸キー名</param>
		''' <param name="pclsYokoData">横軸データ</param>
		''' <remarks>
		''' 2010/10/07 新規作成　CS)松本<BR/>
		''' </remarks>
		''' ---------------------------------------------
		Public Sub New(ByVal pTateKey As String, ByVal pTateName As String, ByVal pclsYokoData As List(Of clsYoko))
			TateKey = pTateKey
			TateName = pTateName
			LstYokoData = New List(Of clsYoko)
			If pclsYokoData.Count > 0 Then
				For i As Integer = 0 To pclsYokoData.Count - 1
					With pclsYokoData(i)
						LstYokoData.Add(New clsYoko(.YokoKey1, .YokoKey2, .YokoName, .YokoValue))
					End With
				Next
			End If
		End Sub
	End Class

	''' ---------------------------------------------
	''' <summary>
	''' 横軸情報
	''' </summary>
	''' <remarks>
	''' 2010/10/07 新規作成　CS)松本<BR/>
	''' </remarks>
	''' ---------------------------------------------
	Public Class clsYoko
		Public YokoKey1 As String
		Public YokoKey2 As String
		Public YokoName As String
		Public YokoValue As Integer

		''' ---------------------------------------------
		''' <summary>
		''' コンストラクタ
		''' </summary>
		''' <param name="pYokoKey1">横軸キー１</param>
		''' <param name="pYokoKey2">横軸キー２</param>
		''' <param name="pYokoName">横軸キー名</param>
		''' <param name="pYokoValue">値</param>
		''' <remarks>
		''' 2010/10/07 新規作成　CS)松本<BR/>
		''' </remarks>
		''' ---------------------------------------------
		Public Sub New(ByVal pYokoKey1 As String, ByVal pYokoKey2 As String, ByVal pYokoName As String, ByVal pYokoValue As Integer)
			YokoKey1 = pYokoKey1
			YokoKey2 = pYokoKey2
			YokoName = pYokoName
			YokoValue = pYokoValue
		End Sub
	End Class

	'病院名
	Private datHspName As datHspName_OneRec = Nothing

	'雛形シート名（プレビュー・印刷用）
	Private pBaseSheetNm As String

	'EXCEL出力用（書式種類）
	Public Enum Enum_CellFmtType
		TypeString = 0	'文字列
		TypeDate = 1	'日付
		TypeInteger = 2	'数値
	End Enum

	'パラメータシートのセル情報
	Public Structure PrmShtCellInfo
		Dim Name As String							'セル名称
		Dim FormatType As Enum_CellFmtType		'書式
		Dim ColIdx As Integer						'列
		Dim RowIdx As Integer						'行
		Dim StrValue As String						'設定値

		''' ---------------------------------------------
		''' <summary>
		''' コンストラクタ
		''' </summary>
		''' <param name="pName">セル名称</param>
		''' <param name="pFormatType">書式</param>
		''' <param name="pColIdx">列</param>
		''' <param name="pRowIdx">行</param>
		''' <param name="pStrValue">設定値</param>
		''' <remarks>
		''' 2010/10/07 新規作成　CS)松本<BR/>
		''' </remarks>
		''' ---------------------------------------------
		Sub New(ByVal pName As String, _
		  ByVal pFormatType As Enum_CellFmtType, _
		  ByVal pColIdx As Integer, ByVal pRowIdx As Integer, _
		  ByVal pStrValue As String)
			With Me
				.Name = pName
				.FormatType = pFormatType
				.ColIdx = pColIdx
				.RowIdx = pRowIdx
				.StrValue = pStrValue
			End With
		End Sub
	End Structure

	'データシートの列情報
	Public Structure DataShtColInfo
		Dim Name As String							'列名
		Dim FormatType As Enum_CellFmtType		'書式
		Dim ColIdx As Integer						'列

		''' ---------------------------------------------
		''' <summary>
		''' コンストラクタ
		''' </summary>
		''' <param name="pName">セル名称</param>
		''' <param name="pFormatType">書式</param>
		''' <param name="pColIdx">列</param>
		''' <remarks>
		''' 2010/10/07 新規作成　CS)松本<BR/>
		''' </remarks>
		''' ---------------------------------------------
		Sub New(ByVal pName As String, _
		  ByVal pFormatType As Enum_CellFmtType, _
		  ByVal pColIdx As Integer)
			With Me
				.Name = pName
				.FormatType = pFormatType
				.ColIdx = pColIdx
			End With
		End Sub
	End Structure

	'出力用データクラス
	Public cPutTate As New List(Of clsTate)

	'ヘッダ及びパラメータシート用設定値
	Public pPrmShtData As PrmShtData
	Public Structure PrmShtData
		Dim PrintMode As Enum_PrintMode				'帳票種類
		Dim HspName As String						'病院名
		Dim ListName As String						'帳票名
		Dim PutDay As String						'処理日
		Dim PutTime As String						'処理時刻
		Dim Period As String						'対象期間（編集用）
		Dim TateNm As String						'縦軸名称
		Dim PresentDay As String					'現在（yyyy/MM/dd現在貸出中）
		Dim IssueDtFrom As String					'貸出日From
		Dim IssueDtTo As String						'貸出日To
		Dim BaseDtFrom As String					'基準日From
		Dim BaseDtTo As String						'基準日To
		Dim MngItemNm As String						'管理物名
		Dim ListNumber As String					'帳票番号
		Dim DspZeroRowNm As String					'ゼロ行表示（名称）
		Dim DspAbbreviationNm As String				'略称表示（横軸）
		Dim DspOrderNm As String					'表示順
		Dim ReplaceZeroCharacter As String			'統計ゼロ置換文字
	End Structure

	'プレビュー・印刷用：シートデータ情報格納用領域
	Public pBaseShtInfo As BaseShtCellInfo
	Public Structure BaseShtCellInfo
		Dim TitleHspNm As CellColRow			'病院名
		Dim TitleListNm As CellColRow			'帳票名
		Dim TitlePeriod As CellColRow			'期間
		Dim TitleTate As CellColRow				'縦軸タイトル
		Dim StartTitleTate As CellColRow		'縦軸タイトルデータ開始
		Dim StartTitleYoko As CellColRow		'横軸タイトルデータ開始
		Dim StepTitleYoko As Integer			'横軸タイトルの設定間隔
		Dim StartData As CellColRow				'データ開始

		''' ---------------------------------------------
		''' <summary>
		''' コンストラクタ
		''' </summary>
		''' <param name="pPrtMode">帳票種類</param>
		''' <remarks>
		''' 2010/10/07 新規作成　CS)松本<BR/>
		''' </remarks>
		''' ---------------------------------------------
		Sub New(ByVal pPrtMode As Enum_PrintMode)
			With Me
				.TitleHspNm = New CellColRow(1, 1)
				.TitleListNm = New CellColRow(1, 2)
				.TitlePeriod = New CellColRow(1, 3)
				.TitleTate = New CellColRow(1, 4)
				.StartTitleYoko = New CellColRow(2, 4)
				If pPrtMode = Enum_PrintMode.Stat_OnBusiness Then
					.StartTitleTate = New CellColRow(1, 7)
					.StepTitleYoko = 3
					.StartData = New CellColRow(2, 7)
				Else
					.StartTitleTate = New CellColRow(1, 6)
					.StepTitleYoko = 1
					.StartData = New CellColRow(2, 6)
				End If
			End With
		End Sub
	End Structure

	'セルの行列（構造体）
	Public Structure CellColRow
		Dim Col As Integer		'列
		Dim Row As Integer		'行

		''' ---------------------------------------------
		''' <summary>
		''' コンストラクタ
		''' </summary>
		''' <param name="pCol">列</param>
		''' <param name="pRow">行</param>
		''' <remarks>
		''' 2010/10/07 新規作成　CS)松本<BR/>
		''' </remarks>
		''' ---------------------------------------------
		Sub New(ByVal pCol As Integer, ByVal pRow As Integer)
			With Me
				.Col = pCol
				.Row = pRow
			End With
		End Sub
	End Structure

#End Region

#Region "コンスタント"

	'印刷モード
	Public Enum Enum_PrintMode As Integer
		None = 0					'該当なし
		L_DivByPurpose = 1			'貸出件数（借用者部門×貸出目的）
		L_PurposeByMonth = 2		'貸出件数（貸出目的×貸出月）
		U_DivByMonth = 3			'未返却件数（借用者部門×貸出月）
		U_BorrowerByMonth = 4		'未返却件数（借用者×貸出月）
		Stat_OnBusiness = 5			'業務量統計
	End Enum

	'縦軸横軸固定キー
	Public Const CST_TATEYOKO_KEY_TOTAL As String = "TOTAL"
	Public Const CST_TATEYOKO_NM_TOTAL As String = "総数"
	Public Const CST_TATEYOKO_KEY_NONE As String = "NONE"
	Public Const CST_TATEYOKO_NM_NONE As String = "該当無し"
	Public Const CST_TATEYOKO_KEY_ADD As String = "1"		'新規作成
	Public Const CST_TATEYOKO_KEY_LEND As String = "2"		'貸出
	Public Const CST_TATEYOKO_KEY_RETURN As String = "3"	'返却
	Public Const CST_TATEYOKO_NM_ADD As String = "_新規作成"
	Public Const CST_TATEYOKO_NM_LEND As String = "_貸出"
	Public Const CST_TATEYOKO_NM_RETURN As String = "_返却"
	'プレビュー・印刷用：テンプレートファイル名
	Private Const CST_FIXED_TEMPLATE_FILENAME As String = "..\bin\BT4LST.xls"
	'デフォルトの設定値
	Private Const CST_DEF_CopyCnt As Integer = 1
	'プレビュー・印刷用：行コピー元の位置
	Private Const CST_COPYROW_OFFSET_1 As Integer = 1	'開始行
	Private Const CST_COPYROW_OFFSET_2 As Integer = 2	'中間行
	Private Const CST_COPYROW_OFFSET_3 As Integer = 3	'最終行
	'帳票Excel用：データシートの見出し行の位置
	Private Const CST_DEF_HEADER_ROW As Integer = 1
	'帳票Excel用：縦軸項目の列位置
	Public Const CST_DEF_HEADER_COL As Integer = 1
	'帳票Excel用：横軸項目の開始列位置
	Private Const CST_DEF_HEADER_START_COL As Integer = 2
	'帳票Excel用：データ開始行・列
	Private Const CST_DEF_DETAIL_START_COL As Integer = 2
	Public Const CST_DEF_DETAIL_START_ROW As Integer = 2
	'帳票番号（配列のインデックスは Enum_PrintMode に対応）
	Private ListNo() As String = New String() { _
	 String.Empty, "00001", "00002", "00003", "00004", "00005" _
	 }
	'帳票Excel用：帳票タイトル接頭語（配列のインデックスは Enum_PrintMode に対応）
	Private ListNmPrefix() As String = New String() { _
	 String.Empty, _
	 "借用者部門別・貸出目的別・貸出件数", _
	 "貸出目的別・貸出月別・貸出件数", _
	 "借用者部門別・貸出月別・未返却件数", _
	 "借用者別・貸出月別・未返却件数", _
	 "業務量統計" _
	 }
	'帳票タイトル（追加文言）
	Private Const CST_LST_DEF_LISTNM_ADD1 As String = "[管理物]"
	Private Const CST_LST_DEF_LISTNM_ADD2 As String = "（年月日時分現在貸出中）"
	Private Const CST_LST_REP_MNGITEM As String = "管理物"
	Private Const CST_LST_REP_DATE As String = "年月日時分"
	Private Const CST_LST_DEF_PERIOD As String = "（対象期間From～対象期間To）"
	Private Const CST_LST_REP_PERIOD_From As String = "対象期間From"
	Private Const CST_LST_REP_PERIOD_To As String = "対象期間To"
	'プレビュー・印刷用：帳票見出し用（貸出月編集用）
	Private Const CST_LST_ISSUE_DT_MONTH As String = "ｘｘ月"
	Private Const CST_LST_REP_ISSUE_DT As String = "ｘｘ"
	'プレビュー・印刷用：雛形シート名
	Private Const CST_SHT_ExceptStat_OnBusiness As String = "貸出管理＿貸出・未返却＿書式"
	Private Const CST_SHT_Stat_OnBusiness As String = "貸出管理＿業務量＿書式"
	'帳票Excel用：パラメータシート項目
	Private Enum Enum_PrmShtItm As Integer
		HspName					'病院名
		ListName				'帳票名
		PutDay					'処理日
		PutTime					'処理時刻
		IssueDtFrom				'貸出日From
		IssueDtTo				'貸出日To
		MngItemNm				'管理物名
		BaseDtFrom				'基準日From
		BaseDtTo				'基準日To
		ListNumber				'帳票番号
		DspZeroRowNm			'ゼロ行表示（名称）
		DspAbbreviationNm		'略称表示（横軸）
		DspOrderNm				'表示順
	End Enum

	'Excelの最大列数、最大行数、拡張子の桁数
	Private Const CST_SHT_MAX_COL_2007 As Integer = 16384	'最大列数(Excel2007,2010)
	Private Const CST_SHT_MAX_ROW_2007 As Integer = 1048576	'最大行数(Excel2007,2010)
	Private Const CST_SHT_MAX_COL_2003 As Integer = 256		'最大列数(Excel2003)
	Private Const CST_SHT_MAX_ROW_2003 As Integer = 65536	'最大行数(Excel2003)
	Private Const CST_BOOK_EXT_LEN_2007 As Integer = 4		'拡張子の桁数(Excel2007,2010)
	Private Const CST_STR_DOT As String = "."
	Private Const CST_HHMM_FORMAT As String = "HH:mm"

#End Region

#Region "メソッド"

	''' ---------------------------------------------
	''' <summary>
	''' 縦軸キーに対するIndex取得
	''' </summary>
	''' <param name="cTate">縦軸</param>
	''' <param name="pTate1">縦キー名</param>
	''' <returns>位置</returns>
	''' <remarks>
	''' 2010/10/07 新規作成　CS)松本<BR/>
	''' </remarks>
	''' ---------------------------------------------
	Public Function GetTateFindIndex(ByVal cTate As List(Of clsTate), ByVal pTate1 As String) As Integer
		Dim iTate As Integer
		Try
			pFindKey_Tate = pTate1
			iTate = cTate.FindIndex(AddressOf TateFindKey)
		Catch ex As Exception
			Throw
		End Try
		Return iTate
	End Function

	''' ---------------------------------------------
	''' <summary>
	''' 横軸キーに対するIndex取得
	''' </summary>
	''' <param name="cYoko">横軸</param>
	''' <param name="pYoko1">横キー名(1)</param>
	''' <param name="pYoko2">横キー名(2)</param>
	''' <returns>位置</returns>
	''' <remarks>
	''' 2010/10/07 新規作成　CS)松本<BR/>
	''' </remarks>
	''' ---------------------------------------------
	Public Function GetYokoFindIndex(ByVal cYoko As List(Of clsYoko), ByVal pYoko1 As String, ByVal pYoko2 As String) As Integer
		Dim iYoko As Integer
		Try
			pFindKey_Yoko1 = pYoko1
			pFindKey_Yoko2 = pYoko2
			iYoko = cYoko.FindIndex(AddressOf YokoFindKey)
		Catch ex As Exception
			Throw
		End Try
		Return iYoko
	End Function

	''' ---------------------------------------------
	''' <summary>
	''' 縦軸検索キー取得
	''' </summary>
	''' <param name="cTate">縦軸</param>
	''' <returns>結果</returns>
	''' <remarks>
	''' 2010/10/07 新規作成　CS)松本<BR/>
	''' </remarks>
	''' ---------------------------------------------
	Private Function TateFindKey(ByVal cTate As clsTate) As Boolean
		Try
			If cTate.TateKey = pFindKey_Tate Then
				Return True
			Else
				Return False
			End If
		Catch ex As Exception
			Throw
		End Try
	End Function

	''' ---------------------------------------------
	''' <summary>
	''' 横軸検索キー取得
	''' </summary>
	''' <param name="cYoko">横軸</param>
	''' <returns>結果</returns>
	''' <remarks>
	''' 2010/10/07 新規作成　CS)松本<BR/>
	''' </remarks>
	''' ---------------------------------------------
	Private Function YokoFindKey(ByVal cYoko As clsYoko) As Boolean
		Try
			If cYoko.YokoKey1 = pFindKey_Yoko1 And _
			 cYoko.YokoKey2 = pFindKey_Yoko2 Then
				Return True
			Else
				Return False
			End If
		Catch ex As Exception
			Throw
		End Try
	End Function

	''' ---------------------------------------------
	''' <summary>
	''' 印刷・プレビュー処理
	''' </summary>
	''' <param name="pFrm">統計表選択</param>
	''' <param name="pParmSheetData">パラメータ情報</param>
	''' <param name="cTate">取得データクラス</param>
	''' <param name="pPrintFlg">TRUE:印刷 FALSE:プレビュー</param>
	''' <returns>結果</returns>
	''' <remarks>
	''' 2010/10/07 新規作成　CS)松本<BR/>
	''' </remarks>
	''' ---------------------------------------------
	Public Function ExePrint(ByRef pFrm As LST010F010, ByVal pParmSheetData As PrmShtData, ByVal cTate As List(Of clsTate), ByVal pPrintFlg As Boolean) As Boolean
		pFrm.log(clsSysMst.logLevel.DBG, "ExePrint", "印刷・プレビュー処理 Start")
		Dim bResult As Boolean = False
		Dim cliExcelFunc As clsExcelFunc
		Try
			cliExcelFunc = New clsExcelFunc
			'パラメータ情報
			pPrmShtData = pParmSheetData
			'フルパスを取得
			Dim sFileNm As String = My.Computer.FileSystem.CombinePath(Application.StartupPath, CST_FIXED_TEMPLATE_FILENAME)
			'雛型ファイルのチェック
			If Not File.Exists(sFileNm) Then
				pFrm.showMsg("E0003", "雛型ファイルが存在しない", "出力", "必要ファイル：" & sFileNm)
				Return bResult
			End If
			'雛形シート名 と シート情報の設定
			If pPrmShtData.PrintMode = Enum_PrintMode.Stat_OnBusiness Then
				'業務量統計の場合
				pBaseSheetNm = CST_SHT_Stat_OnBusiness
			Else
				pBaseSheetNm = CST_SHT_ExceptStat_OnBusiness
			End If
			pBaseShtInfo = New BaseShtCellInfo(pPrmShtData.PrintMode)
			'雛形シート名が存在しない場合はエラー
			Dim arSheetNm As ArrayList = cliExcelFunc.getSheetNames(sFileNm)
			Dim bFindSht As Boolean = False
			For i As Integer = 0 To arSheetNm.Count - 1
				If arSheetNm(i).ToString = pBaseSheetNm Then
					bFindSht = True
					Exit For
				End If
			Next
			If Not bFindSht Then
				pFrm.showMsg("E0003", "雛型シートが存在しない", "出力", Nothing)
				Return bResult
			End If
			'最大行列チェック
			Dim errMsgCd As String = String.Empty
			Dim errMsgParm() As String = Nothing
			If Not ChkMaxRowColForExcel(pFrm, cTate, sFileNm, False, errMsgCd, errMsgParm) Then
				pFrm.showMsg(errMsgCd, errMsgParm)
				Return bResult
			End If
			'出力用縦軸データ
			cPutTate = cTate
			'Excel出力
			bResult = PutExcel(pFrm, pPrintFlg, sFileNm, pBaseSheetNm, False)
		Catch ex As Exception
			Throw
		End Try
		Return bResult
	End Function

	''' ---------------------------------------------
	''' <summary>
	''' 各種情報の設定
	''' </summary>
	''' <param name="pFrm">統計表選択</param>
	''' <param name="pReplaceZeroCharacter">統計ゼロ置換文字</param>
	''' <param name="pbPutExcel">帳票Excel出力かどうか</param>
	''' <returns>設定結果</returns>
	''' <remarks>
	''' 2010/10/07 新規作成　CS)松本<BR/>
	''' </remarks>
	''' ---------------------------------------------
	Public Function SetVariousInfo(ByRef pFrm As LST010F010, ByVal pReplaceZeroCharacter As String, ByVal pbPutExcel As Boolean) As Boolean
		pFrm.log(clsSysMst.logLevel.DBG, "SetVariousInfo", "各種情報の設定 Start")
		Dim cliHspName As clsXTM_HSPNAME
		Try
			cliHspName = New clsXTM_HSPNAME
			'病院情報の取得
			datHspName = cliHspName.getHspName_OneRec_DataClass
			If datHspName Is Nothing Then
				datHspName = New datHspName_OneRec
			End If
			'画面からの情報取得
			pPrmShtData = Nothing
			With pPrmShtData
				' 帳票種類の特定
				If pFrm.rdo021LST010F010.Checked Then
					.PrintMode = Enum_PrintMode.L_DivByPurpose
				ElseIf pFrm.rdo023LST010F010.Checked Then
					.PrintMode = Enum_PrintMode.L_PurposeByMonth
				ElseIf pFrm.rdo033LST010F010.Checked Then
					.PrintMode = Enum_PrintMode.U_DivByMonth
				ElseIf pFrm.rdo035LST010F010.Checked Then
					.PrintMode = Enum_PrintMode.U_BorrowerByMonth
				ElseIf pFrm.rdo042LST010F010.Checked Then
					.PrintMode = Enum_PrintMode.Stat_OnBusiness
				Else
					.PrintMode = Enum_PrintMode.None
				End If
				.HspName = datHspName.HSP_NM
				.PutDay = Now.ToString(clsConst.CST_YYYYMMDD_FORMAT)
				.PutTime = Now.ToString(CST_HHMM_FORMAT)
				.TateNm = pFrm.lbl044LST010F010.Text
				If .PrintMode = Enum_PrintMode.Stat_OnBusiness Then
					.BaseDtFrom = pFrm.dte039LST010F010.DateValue.ToString(clsConst.CST_YYYYMMDD_FORMAT)
					.BaseDtTo = pFrm.dte041LST010F010.DateValue.ToString(clsConst.CST_YYYYMMDD_FORMAT)
					.Period = _
					 CST_LST_DEF_PERIOD.Replace(CST_LST_REP_PERIOD_From, .BaseDtFrom) _
					 .Replace(CST_LST_REP_PERIOD_To, .BaseDtTo)
				Else
					.IssueDtFrom = pFrm.dte007LST010F010.DateValue.ToString(clsConst.CST_YYYYMMDD_FORMAT)
					.IssueDtTo = pFrm.dte009LST010F010.DateValue.ToString(clsConst.CST_YYYYMMDD_FORMAT)
					.Period = _
					 CST_LST_DEF_PERIOD.Replace(CST_LST_REP_PERIOD_From, .IssueDtFrom) _
					 .Replace(CST_LST_REP_PERIOD_To, .IssueDtTo)
					.MngItemNm = pFrm.lbl004LST010F010.Text
				End If
				.ListNumber = ListNo(pPrmShtData.PrintMode)
				.DspZeroRowNm = pFrm.lbl054LST010F010.Text
				.DspAbbreviationNm = pFrm.lbl057LST010F010.Text
				.DspOrderNm = pFrm.lbl060LST010F010.Text
				If pbPutExcel Then
					.ListName = ListNmPrefix(pPrmShtData.PrintMode)
					If .PrintMode <> Enum_PrintMode.Stat_OnBusiness Then
						'業務量統計以外の場合
						.ListName &= CST_LST_DEF_LISTNM_ADD1.Replace(CST_LST_REP_MNGITEM, .MngItemNm)
					End If
					If (.PrintMode = Enum_PrintMode.L_DivByPurpose Or _
					 .PrintMode = Enum_PrintMode.L_PurposeByMonth) _
					   AndAlso pFrm.chk011LST010F010.Checked Then
						'貸出件数で貸し出し中のみの場合
						.ListName &= CST_LST_DEF_LISTNM_ADD2.Replace(CST_LST_REP_DATE, .PutDay)
					End If
				Else
					.ListName = pFrm.txt051LST010F010.Text.Trim
					If .PrintMode <> Enum_PrintMode.Stat_OnBusiness Then
						'業務量統計以外の場合
						.ListName &= CST_LST_DEF_LISTNM_ADD1.Replace(CST_LST_REP_MNGITEM, .MngItemNm)
					End If
				End If
				.ReplaceZeroCharacter = pReplaceZeroCharacter
			End With
			Return True
		Catch ex As Exception
			Throw
		Finally
			cliHspName = Nothing
		End Try
	End Function

	''' ---------------------------------------------
	''' <summary>
	''' Excel出力処理
	''' </summary>
	''' <param name="pFrm">frmBase</param>
	''' <param name="pPrintFlg">TRUE:印刷 FALSE:プレビュー</param>
	''' <param name="pFileNm">ファイル名</param>
	''' <param name="pSheetNm">シート名（表示時の選択シート名）</param>
	''' <param name="pbPutExcel">帳票Excel出力かどうか</param>
	''' <returns>結果情報</returns>
	''' <remarks>
	''' 2010/10/07 新規作成　CS)松本<BR/>
	''' </remarks>
	''' ---------------------------------------------
	Public Function PutExcel(ByRef pFrm As frmBase, ByVal pPrintFlg As Boolean, ByVal pFileNm As String, ByVal pSheetNm As String, ByVal pbPutExcel As Boolean) As Boolean
		pFrm.log(clsSysMst.logLevel.DBG, "PutExcel", "Excel出力処理 Start")
		Try
			' オブジェクトのインスタンス作成
			Using xlApp As clsExcel = New clsExcel(pPrintFlg)
				' １ページの基準となるホームポジションの初期値を、シートの左上に設定する。
				Dim posHome As clsExcel.PosInfo = New clsExcel.PosInfo(1, 1)
				' Workbooks コレクション
				Using xlBooks As clsExcelBooks = New clsExcelBooks(xlApp, pPrintFlg)
					' 出力用 Workbook、ひな形 Workbook
'(M) STR V4-11020-000 005 20110812 FJSK)荒川 XXX号 病歴大将V4PKG問題点No103 EXCEL出力でテンプレートと同じファイル名で出力するとエラー対応
'					Using xlOBook As clsExcelBook = New clsExcelBook(xlBooks, pPrintFlg), _
'					   xlMBook As clsExcelBook = New clsExcelBook(xlBooks, pFileNm, True)
					Using xlOBook As clsExcelBook = New clsExcelBook(xlBooks, pPrintFlg)
'(M) END V4-11020-000 005 20110812
'(A) STR V4-14044-000 003 20130717 ID)鐘井 病歴大将のバージョン対応
                        Try
'(A) END V4-14044-000 003 20130717 ID)鐘井 病歴大将のバージョン対応
                        ' 出力用 Worksheets、ひな形 Worksheets
'(M) STR V4-11020-000 005 20110812 FJSK)荒川 XXX号 病歴大将V4PKG問題点No103 EXCEL出力でテンプレートと同じファイル名で出力するとエラー対応
'						Using xlOSheets As clsExcelSheets = New clsExcelSheets(xlOBook), _
'						   xlMSheets As clsExcelSheets = New clsExcelSheets(xlMBook)
                            Using xlOSheets As clsExcelSheets = New clsExcelSheets(xlOBook)
'(M) END V4-11020-000 005 20110812
                                ' 出力用 Worksheet
                                Using xlOSheet As clsExcelSheet = New clsExcelSheet
                                ' 先頭をダミー用シートに設定
                                    If xlOSheets.Count = 0 Then
                                        ' シートがない場合は新しいシートを追加
                                        xlOSheets.Add()
                                    Else
                                        ' シートがある場合は１つだけ残し、以外を削除する
                                        For i As Integer = xlOSheets.Count To 2 Step -1
                                            xlOSheet.SetSheet(xlOSheets, i)
                                            xlOSheet.Delete()
                                        Next
                                    End If
                                    xlOSheet.SetSheet(xlOSheets, 1)
'(A) STR V4-11020-000 004 20110812 FJSK)荒川 XXX号 病歴大将V4PKG問題点No103 EXCEL出力でテンプレートと同じファイル名で出力するとエラー対応
                                    Using xlMBook As clsExcelBook = New clsExcelBook(xlBooks, pFileNm, True)
                                        Using xlMSheets As clsExcelSheets = New clsExcelSheets(xlMBook)
'(A) END V4-11020-000 004 20110812
                                            ' 出力用 Worksheets に、ひな形 Worksheets を追加
                                            xlMSheets.CopyAfterSheets(xlOSheet)
'(A) STR V4-11020-000 004 20110812 FJSK)荒川 XXX号 病歴大将V4PKG問題点No103 EXCEL出力でテンプレートと同じファイル名で出力するとエラー対応
                                        End Using
                                    End Using
'(A) END V4-11020-000 004 20110812
                                    '不要な書式シートを削除（帳票Excel出力以外の場合のみ）
                                    If Not pbPutExcel Then
                                        Dim delSheetNm As String
                                        If pPrmShtData.PrintMode = Enum_PrintMode.Stat_OnBusiness Then
                                            delSheetNm = CST_SHT_ExceptStat_OnBusiness
                                        Else
                                            delSheetNm = CST_SHT_Stat_OnBusiness
                                        End If
                                        For i As Integer = xlOSheets.Count To 1 Step -1
                                            xlOSheet.SetSheet(xlOSheets, i)
                                            If xlOSheet.Name = delSheetNm Then
                                                xlOSheet.Delete()
                                                Exit For
                                            End If
                                        Next
                                        xlOSheet.SetSheet(xlOSheets, 1)
                                    End If
                                    ' 項目用 Range
                                    Using xlRange As clsExcelRange = New clsExcelRange, _
                                    xlRow As clsExcelRow = New clsExcelRow
                                        If Not pbPutExcel Then
                                            '帳票Excel出力以外の場合
                                            PutExcelDataForPrev(pFrm, xlApp, posHome, xlOSheets, xlOSheet, xlRange)
                                        Else
                                            PutExcelData(pFrm, xlApp, posHome, xlOSheets, xlOSheet, xlRange)
                                        End If
                                    End Using
                                    ' ダミー用シートの削除
                                    xlOSheet.SetSheet(xlOSheets, 1)
                                    xlOSheet.Delete()
                                    If Not pbPutExcel Then
                                        '帳票Excel出力以外の場合
                                        'シート選択
                                        xlOSheet.SetSheet(xlOSheets, 1)
                                        xlOSheet.SheetSelect()
                                        If pPrintFlg Then
                                            '印刷
                                            xlOSheet.putPrintOut(CST_DEF_CopyCnt)
                                        Else
                                            'プレビュー
                                            xlApp.setVisible(True, pFrm)
                                        End If
                                    Else
                                        '帳票Excel出力の場合
                                        'シート選択
                                        xlOSheet.SetSheet(xlOSheets, IIf(String.IsNullOrEmpty(pSheetNm), 1, pSheetNm))
                                        xlOSheet.SheetSelect()
                                        '表示
                                        xlApp.setVisible(True, pFrm)
                                    End If
                                End Using
                            End Using
'(A) STR V4-14044-000 009 20130717 ID)鐘井 病歴大将のバージョン対応
                        Catch ex As Exception
                            'エラー発生のため、解放フラグを設定
                            xlApp.setError()
                            xlBooks.setError()
                            xlOBook.setError()
                            Throw
                        End Try
'(A) END V4-14044-000 009 20130717 ID)鐘井 病歴大将のバージョン対応
                    End Using
				End Using
			End Using
			'正常処理
			Return True
		Catch ex As Exception
			Throw
		End Try
	End Function

	''' ---------------------------------------------
	''' <summary>
	''' プレビュー・印刷用データ出力
	''' </summary>
	''' <param name="pFrm">frmBase</param>
	''' <param name="xlApp">Excelオブジェクト</param>
	''' <param name="posHome">ホームポジションの初期値</param>
	''' <param name="xlOSheets">出力用 Worksheets</param>
	''' <param name="xlOSheet">出力用 Worksheet</param>
	''' <param name="xlRange">項目用 Range</param>
	''' <remarks>
	''' 2010/10/07 新規作成　CS)松本<BR/>
	''' </remarks>
	''' ---------------------------------------------
	Private Sub PutExcelDataForPrev(ByRef pFrm As frmBase, _
	  ByRef xlApp As clsExcel, _
	  ByVal posHome As clsExcel.PosInfo, _
	  ByRef xlOSheets As clsExcelSheets, _
	  ByRef xlOSheet As clsExcelSheet, _
	  ByRef xlRange As clsExcelRange _
	  )
		pFrm.log(clsSysMst.logLevel.DBG, "PutExcelDataForPrev", "プレビュー・印刷用データ出力 Start")
		Try
			xlOSheet.SetSheet(xlOSheets, pBaseSheetNm)
			'＊＊＊＊＊＊＊＊＊＊＊＊＊＊＊＊＊＊＊＊＊＊＊＊＊＊＊＊＊＊＊＊＊＊＊＊＊＊＊＊＊
			'雛形データシートの書式設定（書式情報をコピーする）
			'書式情報をコピー（列）
			Dim copyCntColMin As Integer = pBaseShtInfo.StartTitleYoko.Col
			Dim copyCntColMax As Integer = pBaseShtInfo.StartTitleYoko.Col + cPutTate(0).LstYokoData.Count - 1
			If copyCntColMin < copyCntColMax Then
				Dim sCopyPos_From As String
				Dim sCopyPos_To As String
				'コピー時の最大行位置
				Dim iMaxCopyRowIdx As Integer = pBaseShtInfo.StartTitleTate.Row + CST_COPYROW_OFFSET_3	 'コピー元のデータ行（書式設定済）が３行あるため
				sCopyPos_From = xlApp.getMultiCellStyle(posHome, _
				  New clsExcel.PosInfo(copyCntColMin, pBaseShtInfo.StartTitleYoko.Row), _
				  New clsExcel.PosInfo(pBaseShtInfo.StartData.Col + pBaseShtInfo.StepTitleYoko - 1, iMaxCopyRowIdx))
				sCopyPos_To = xlApp.getMultiCellStyle(posHome, _
				  New clsExcel.PosInfo(copyCntColMin + pBaseShtInfo.StepTitleYoko, pBaseShtInfo.StartTitleYoko.Row), _
				  New clsExcel.PosInfo(copyCntColMax, iMaxCopyRowIdx))
				Using xlCopyRange_From As New clsExcelRange(xlOSheet, sCopyPos_From), _
				 xlCopyRange_To As New clsExcelRange(xlOSheet, sCopyPos_To)
					xlCopyRange_From.Copy(xlCopyRange_To)
				End Using
			End If
			'書式情報をコピー（行）
			'　※行の場合は総数行１行を除いたデータ行数に応じて行コピーを行う
			'　　（３行以内の場合は不用な行を削除する）
			Dim iDataRowCnt As Integer = cPutTate.Count - 1	'総計行の１行を除く
			Using xlBaseRow1 As New clsExcelRow(xlOSheet, pBaseShtInfo.StartTitleTate.Row + CST_COPYROW_OFFSET_1), _
			 xlBaseRow2 As New clsExcelRow(xlOSheet, pBaseShtInfo.StartTitleTate.Row + CST_COPYROW_OFFSET_2), _
			 xlBaseRow3 As New clsExcelRow(xlOSheet, pBaseShtInfo.StartTitleTate.Row + CST_COPYROW_OFFSET_3)
				Select Case iDataRowCnt
					Case Is = CST_COPYROW_OFFSET_1	'総数を除くデータが１行の場合
						xlBaseRow2.Delete()
						xlBaseRow1.Delete()
					Case Is = CST_COPYROW_OFFSET_2	'総数を除くデータが２行の場合
						xlBaseRow2.Delete()
					Case Is = CST_COPYROW_OFFSET_3	'総数を除くデータが３行の場合
						'何もしない
					Case Else						'総数を除くデータが３行を超える場合
						'２行目を挿入
						For i As Integer = 0 To cPutTate.Count - 1 - CST_COPYROW_OFFSET_3 - 1  '既に書式設定済みの３行及び総数行の１行を除く
							xlBaseRow2.Insert()
						Next
						'２行目の情報をコピー
						Dim iStartRow As Integer = pBaseShtInfo.StartTitleTate.Row + CST_COPYROW_OFFSET_2 + 1	'２行目の次の行
						Using xlCopyRow_To As New clsExcelRow(xlOSheet, _
						  xlApp.getMultiRowStyle(posHome.X, _
						   iStartRow, iStartRow + iDataRowCnt - CST_COPYROW_OFFSET_3 - 1))
							xlBaseRow2.Copy(xlCopyRow_To)
						End Using
				End Select
			End Using
			'＊＊＊＊＊＊＊＊＊＊＊＊＊＊＊＊＊＊＊＊＊＊＊＊＊＊＊＊＊＊＊＊＊＊＊＊＊＊＊＊＊
			'タイトル設定
			Dim sHeaderPos As String
			'病院名
			sHeaderPos = xlApp.getCellStyle(posHome, _
			   New clsExcel.PosInfo(pBaseShtInfo.TitleHspNm.Col, pBaseShtInfo.TitleHspNm.Row))
			xlRange.SetRangeValue(xlOSheet, sHeaderPos, pPrmShtData.HspName)
			'帳票名
			sHeaderPos = xlApp.getCellStyle(posHome, _
			   New clsExcel.PosInfo(pBaseShtInfo.TitleListNm.Col, pBaseShtInfo.TitleListNm.Row))
			xlRange.SetRangeValue(xlOSheet, sHeaderPos, pPrmShtData.ListName)
			'期間
			sHeaderPos = xlApp.getCellStyle(posHome, _
			   New clsExcel.PosInfo(pBaseShtInfo.TitlePeriod.Col, pBaseShtInfo.TitlePeriod.Row))
			xlRange.SetRangeValue(xlOSheet, sHeaderPos, pPrmShtData.Period)
			'縦軸のタイトル設定
			sHeaderPos = xlApp.getCellStyle(posHome, _
			   New clsExcel.PosInfo(pBaseShtInfo.TitleTate.Col, pBaseShtInfo.TitleTate.Row))
			xlRange.SetRangeValue(xlOSheet, sHeaderPos, pPrmShtData.TateNm)
			'横軸タイトル設定
			Dim iStartCol As Integer
			Dim iItem As Integer = 0
			Dim sSetValue As String
			'１件目のデータファイルからヘッダ情報を設定する
			Do Until iItem > cPutTate(0).LstYokoData.Count - 1
				iStartCol = pBaseShtInfo.StartTitleYoko.Col + iItem
				sHeaderPos = xlApp.getCellStyle(posHome, _
				  New clsExcel.PosInfo(iStartCol, pBaseShtInfo.StartTitleYoko.Row))
				'貸出年月で総数以外の場合は、再編集を行う
				With cPutTate(0)
					If (pPrmShtData.PrintMode = Enum_PrintMode.L_PurposeByMonth Or _
					 pPrmShtData.PrintMode = Enum_PrintMode.U_DivByMonth Or _
					 pPrmShtData.PrintMode = Enum_PrintMode.U_BorrowerByMonth) And _
					(.LstYokoData(iItem).YokoKey1 <> CST_TATEYOKO_KEY_TOTAL And _
					 .LstYokoData(iItem).YokoKey2 <> CST_TATEYOKO_KEY_TOTAL) Then
						sSetValue = CST_LST_ISSUE_DT_MONTH.Replace(CST_LST_REP_ISSUE_DT, _
						  CInt(.LstYokoData(iItem).YokoName.Substring(.LstYokoData(iItem).YokoName.Length - 2)).ToString)
					Else
						sSetValue = .LstYokoData(iItem).YokoName
					End If
				End With
				xlRange.SetRangeValue(xlOSheet, sHeaderPos, sSetValue)
				iItem += pBaseShtInfo.StepTitleYoko
			Loop
			'＊＊＊＊＊＊＊＊＊＊＊＊＊＊＊＊＊＊＊＊＊＊＊＊＊＊＊＊＊＊＊＊＊＊＊＊＊＊＊＊＊
			'データを配列形式に取得し、データを出力する
			Dim strTitleTateData(,) As String = Nothing
			Dim strDetail(,) As String = Nothing
			SetArray(pFrm, strDetail, strTitleTateData)
			Dim maxDataRow As Integer = pBaseShtInfo.StartTitleTate.Row + strTitleTateData.GetLength(0) - 1
			Dim maxDataCol As Integer = pBaseShtInfo.StartData.Col + cPutTate(0).LstYokoData.Count - 1
			'縦軸タイトルの設定
			xlRange.SetAreaValue(xlOSheet.Worksheet, pBaseShtInfo.StartTitleTate.Col, pBaseShtInfo.StartTitleTate.Row, pBaseShtInfo.StartTitleTate.Col, maxDataRow, strTitleTateData)
			'データ行の設定
			xlRange.SetAreaValue(xlOSheet.Worksheet, pBaseShtInfo.StartData.Col, pBaseShtInfo.StartData.Row, maxDataCol, maxDataRow, strDetail)
		Catch ex As Exception
			Throw
		End Try
	End Sub

	''' ---------------------------------------------
	''' <summary>
	''' 帳票Excelデータ出力
	''' </summary>
	''' <param name="pFrm">frmBase</param>
	''' <param name="xlApp">Excelオブジェクト</param>
	''' <param name="posHome">ホームポジションの初期値</param>
	''' <param name="xlOSheets">出力用 Worksheets</param>
	''' <param name="xlOSheet">出力用 Worksheet</param>
	''' <param name="xlRange">項目用 Range</param>
	''' <remarks>
	''' 2010/10/07 新規作成　CS)松本<BR/>
	''' </remarks>
	''' ---------------------------------------------
	Private Sub PutExcelData(ByRef pFrm As frmBase, _
	  ByRef xlApp As clsExcel, _
	  ByVal posHome As clsExcel.PosInfo, _
	  ByRef xlOSheets As clsExcelSheets, _
	  ByRef xlOSheet As clsExcelSheet, _
	  ByRef xlRange As clsExcelRange _
	  )
		pFrm.log(clsSysMst.logLevel.DBG, "PutExcelData", "帳票Excelデータ出力 Start")
		Try
			'パラメータシート情報の設定
			Dim prmShtCellInfo() As PrmShtCellInfo = New PrmShtCellInfo() { _
			 New PrmShtCellInfo(Enum_PrmShtItm.HspName.ToString, Enum_CellFmtType.TypeString, 3, 1, pPrmShtData.HspName), _
			 New PrmShtCellInfo(Enum_PrmShtItm.ListName.ToString, Enum_CellFmtType.TypeString, 3, 2, pPrmShtData.ListName), _
			 New PrmShtCellInfo(Enum_PrmShtItm.PutDay.ToString, Enum_CellFmtType.TypeString, 3, 3, pPrmShtData.PutDay), _
			 New PrmShtCellInfo(Enum_PrmShtItm.PutTime.ToString, Enum_CellFmtType.TypeString, 3, 4, pPrmShtData.PutTime), _
			 New PrmShtCellInfo(Enum_PrmShtItm.IssueDtFrom.ToString, Enum_CellFmtType.TypeString, 3, 7, pPrmShtData.IssueDtFrom), _
			 New PrmShtCellInfo(Enum_PrmShtItm.IssueDtTo.ToString, Enum_CellFmtType.TypeString, 3, 8, pPrmShtData.IssueDtTo), _
			 New PrmShtCellInfo(Enum_PrmShtItm.MngItemNm.ToString, Enum_CellFmtType.TypeString, 2, 9, pPrmShtData.MngItemNm), _
			 New PrmShtCellInfo(Enum_PrmShtItm.BaseDtFrom.ToString, Enum_CellFmtType.TypeString, 3, 11, pPrmShtData.BaseDtFrom), _
			 New PrmShtCellInfo(Enum_PrmShtItm.BaseDtTo.ToString, Enum_CellFmtType.TypeString, 3, 12, pPrmShtData.BaseDtTo), _
			 New PrmShtCellInfo(Enum_PrmShtItm.ListNumber.ToString, Enum_CellFmtType.TypeString, 2, 15, pPrmShtData.ListNumber), _
			 New PrmShtCellInfo(Enum_PrmShtItm.DspZeroRowNm.ToString, Enum_CellFmtType.TypeString, 8, 7, pPrmShtData.DspZeroRowNm), _
			 New PrmShtCellInfo(Enum_PrmShtItm.DspAbbreviationNm.ToString, Enum_CellFmtType.TypeString, 8, 8, pPrmShtData.DspAbbreviationNm), _
			 New PrmShtCellInfo(Enum_PrmShtItm.DspOrderNm.ToString, Enum_CellFmtType.TypeString, 8, 9, pPrmShtData.DspOrderNm) _
			 }
			'パラメータシートの設定
			xlOSheet.SetSheet(xlOSheets, CST_PARAM_SHEET)
			'＊＊＊＊＊＊＊＊＊＊＊＊＊＊＊＊＊＊＊＊＊＊＊＊＊＊＊＊＊＊＊＊＊＊＊＊＊＊＊＊＊
			Dim prmPos As String
			For Each prmInfo As PrmShtCellInfo In prmShtCellInfo
				'パラメータシートのセルName取得
				prmPos = xlApp.getCellStyle(posHome, New clsExcel.PosInfo(prmInfo.ColIdx, prmInfo.RowIdx))
				'パラメータシート書式設定
				Select Case prmInfo.FormatType
					Case Enum_CellFmtType.TypeDate
						xlRange.SetMultiFormat(xlOSheet, prmPos, clsExcel.CST_FORMAT_DATE)
					Case Enum_CellFmtType.TypeInteger
						xlRange.SetMultiFormat(xlOSheet, prmPos, clsExcel.CST_FORMAT_INTEGER)
					Case Else
						'文字列
						xlRange.SetMultiFormat(xlOSheet, prmPos, clsExcel.CST_FORMAT_STRING)
				End Select
				'パラメータシートデータ設定
				xlRange.SetRangeValue(xlOSheet, prmPos, prmInfo.StrValue)
			Next
			'データシートの設定
			xlOSheet.SetSheet(xlOSheets, CST_DATA_SHEET)
			'＊＊＊＊＊＊＊＊＊＊＊＊＊＊＊＊＊＊＊＊＊＊＊＊＊＊＊＊＊＊＊＊＊＊＊＊＊＊＊＊＊
			'データシートの書式設定
			Dim sDetailPos As String
			Dim putEndCol As Integer = CST_DEF_HEADER_COL + cPutTate(0).LstYokoData.Count - 1	'縦軸列の１列を含む
			Dim putEndRow As Integer = CST_DEF_HEADER_ROW + cPutTate.Count - 1					'見出し行の１行を含む
			'（全体）
			sDetailPos = xlApp.getMultiCellStyle(posHome, _
			  New clsExcel.PosInfo(CST_DEF_HEADER_COL, CST_DEF_HEADER_ROW), _
			  New clsExcel.PosInfo(putEndCol, putEndRow))
			xlRange.SetMultiFormat(xlOSheet, sDetailPos, clsExcel.CST_FORMAT_STRING)
			'件数列のみ数値編集
			For iCol As Integer = CST_DEF_DETAIL_START_COL To putEndCol
				sDetailPos = xlApp.getMultiCellStyle(posHome, _
				  New clsExcel.PosInfo(iCol, CST_DEF_HEADER_ROW), _
				  New clsExcel.PosInfo(iCol, putEndRow))
				xlRange.SetMultiFormat(xlOSheet, sDetailPos, clsExcel.CST_FORMAT_INTEGER)
			Next
			'タイトル設定
			Dim sHeaderPos As String
			'縦軸のタイトル設定
			sHeaderPos = xlApp.getCellStyle(posHome, _
			   New clsExcel.PosInfo(CST_DEF_HEADER_COL, CST_DEF_HEADER_ROW))
			xlRange.SetRangeValue(xlOSheet, sHeaderPos, pPrmShtData.TateNm)
			'横軸タイトル設定
			Dim htAddTitle As New Hashtable
			Dim iStartCol As Integer
			Dim sSetValue As String
			If pPrmShtData.PrintMode = Enum_PrintMode.Stat_OnBusiness Then
				'業務量統計の場合は新規・貸出・返却用の追加文言を設定する
				htAddTitle.Add(CST_TATEYOKO_KEY_ADD, CST_TATEYOKO_NM_ADD)
				htAddTitle.Add(CST_TATEYOKO_KEY_LEND, CST_TATEYOKO_NM_LEND)
				htAddTitle.Add(CST_TATEYOKO_KEY_RETURN, CST_TATEYOKO_NM_RETURN)
			End If
			'１件目のデータファイルから見出しを設定する
			For i As Integer = 0 To cPutTate(0).LstYokoData.Count - 1
				iStartCol = CST_DEF_HEADER_START_COL + i
				sHeaderPos = xlApp.getCellStyle(posHome, New clsExcel.PosInfo(iStartCol, CST_DEF_HEADER_ROW))
				With cPutTate(0)
					If pPrmShtData.PrintMode = Enum_PrintMode.Stat_OnBusiness AndAlso _
					 htAddTitle.ContainsKey(.LstYokoData(i).YokoKey1) Then
						sSetValue = .LstYokoData(i).YokoName & htAddTitle(.LstYokoData(i).YokoKey1).ToString
					Else
						sSetValue = .LstYokoData(i).YokoName
					End If
				End With
				xlRange.SetRangeValue(xlOSheet, sHeaderPos, sSetValue)
			Next
			htAddTitle = Nothing
			'＊＊＊＊＊＊＊＊＊＊＊＊＊＊＊＊＊＊＊＊＊＊＊＊＊＊＊＊＊＊＊＊＊＊＊＊＊＊＊＊＊
			'データを配列形式に取得し、データを出力する
			Dim strTitleTateData(,) As String = Nothing
			Dim strDetail(,) As String = Nothing
			SetArray(pFrm, strDetail, strTitleTateData)
			Dim maxDataRow As Integer = CST_DEF_DETAIL_START_ROW + strTitleTateData.GetLength(0) - 1
			Dim maxDataCol As Integer = CST_DEF_DETAIL_START_COL + cPutTate(0).LstYokoData.Count - 1
			'縦軸タイトルの設定
			xlRange.SetAreaValue(xlOSheet.Worksheet, CST_DEF_HEADER_COL, CST_DEF_DETAIL_START_ROW, CST_DEF_HEADER_COL, maxDataRow, strTitleTateData)
			'データ行の設定
			xlRange.SetAreaValue(xlOSheet.Worksheet, CST_DEF_DETAIL_START_COL, CST_DEF_DETAIL_START_ROW, maxDataCol, maxDataRow, strDetail)
		Catch ex As Exception
			Throw
		End Try
	End Sub

	''' ---------------------------------------------
	''' <summary>
	''' 配列に値を設定
	''' </summary>
	''' <param name="pFrm">frmBase</param>
	''' <param name="strDetail">件数データ</param>
	''' <param name="strTitleTateData">縦軸タイトルデータ</param>
	''' <remarks>
	''' 2010/10/07 新規作成　CS)松本<BR/>
	''' </remarks>
	''' ---------------------------------------------
	Private Sub SetArray(ByRef pFrm As frmBase, ByRef strDetail(,) As String, ByRef strTitleTateData(,) As String)
		pFrm.log(clsSysMst.logLevel.DBG, "SetArray", "配列に値を設定 Start")
		Try
			Dim maxCol As Integer = cPutTate(0).LstYokoData.Count - 1
			Dim maxRow As Integer = cPutTate.Count - 1
			ReDim strDetail(maxRow, maxCol)
			ReDim strTitleTateData(maxRow, 0)	'縦軸は１列のみ
			'データ行の設定
			Dim iRow As Integer
			For i As Integer = 0 To cPutTate.Count - 1
				iRow = i
				'縦軸タイトルデータの設定
				strTitleTateData(iRow, 0) = cPutTate(i).TateName
				'件数データの設定
				For iCol As Integer = 0 To maxCol
					If cPutTate(i).LstYokoData(iCol).YokoValue = 0 Then
						strDetail(iRow, iCol) = pPrmShtData.ReplaceZeroCharacter
					Else
						strDetail(iRow, iCol) = cPutTate(i).LstYokoData(iCol).YokoValue
					End If
				Next
			Next
		Catch ex As Exception
			Throw
		End Try
	End Sub

	''' ---------------------------------------------
	''' <summary>
	''' 統計用テンプレートファイル名取得
	''' </summary>
	''' <param name="pFrm">frmBase</param>
	''' <param name="pFileNm">ファイル名</param>
	''' <param name="pbGetFullPath">フルパスで取得するか(True:フルパスで取得する、False:ファイル名のみ取得（テンプレートフォルダ以外の場合はフルパスを取得）)</param>
	''' <remarks>
	''' 2010/10/07 新規作成　CS)松本<BR/>
	''' </remarks>
	''' ---------------------------------------------
	Public Function GetFileNmForStatistics(ByRef pFrm As frmBase, ByVal pFileNm As String, ByVal pbGetFullPath As Boolean) As String
		pFrm.log(clsSysMst.logLevel.DBG, "GetFileNmForStatistics", "統計用テンプレートファイル名取得 Start")
		Dim retFileNm As String = String.Empty
		Dim cliCom As clsCom
		Try
			cliCom = New clsCom
			'空の場合は何もしない
			If String.IsNullOrEmpty(pFileNm) Then
				Return pFileNm
			End If
			Dim ShortFileNm As String
			Dim LongFileNm As String
			Dim bFullPath As Boolean
			If IO.File.Exists(pFileNm) Then
				ShortFileNm = IO.Path.GetFileName(pFileNm)
				LongFileNm = IO.Path.GetFullPath(pFileNm)
				bFullPath = True
			Else
				ShortFileNm = pFileNm
				LongFileNm = String.Empty
				bFullPath = False
			End If
			If pbGetFullPath Then
				'フルパスで取得する場合
				If bFullPath Then
					retFileNm = LongFileNm
				Else
					retFileNm = cliCom.setExcelTemplatePath(ShortFileNm)
				End If
			Else
				'ファイル名を取得する場合
				If Not bFullPath Then
					retFileNm = ShortFileNm
				Else
					If cliCom.setExcelTemplatePath(ShortFileNm) <> LongFileNm Then
						'テンプレートフォルダと異なる場合はそのまま返す
						retFileNm = pFileNm
					Else
						retFileNm = ShortFileNm
					End If
				End If
			End If
		Catch ex As Exception
			Throw
		Finally
			cliCom = Nothing
		End Try
		Return retFileNm
	End Function

	''' ---------------------------------------------
	''' <summary>
	''' Excel用最大行列数チェック
	''' </summary>
	''' <param name="pFrm">frmBase</param>
	''' <param name="cTate">取得データクラス</param>
	''' <param name="pFileNm">ファイル名</param>
	''' <param name="pbPutExcel">帳票Excel出力かどうか</param>
	''' <param name="pErrMsgCd">メッセージコード</param>
	''' <param name="pErrMsgParm">メッセージのパラメータ</param>
	''' <returns>結果</returns>
	''' <remarks>
	''' 2010/10/07 新規作成　CS)松本<BR/>
	''' </remarks>
	''' ---------------------------------------------
	Public Function ChkMaxRowColForExcel(ByRef pFrm As frmBase, ByRef cTate As List(Of clsTate), ByVal pFileNm As String, ByVal pbPutExcel As Boolean, ByRef pErrMsgCd As String, ByRef pErrMsgParm() As String) As Boolean
		pFrm.log(clsSysMst.logLevel.DBG, "ChkMaxRowColForExcel", "Excel用最大行列数チェック Start")
		Dim bResult As Boolean = True
		Try
			Dim sExt As String
			Dim iMaxCol As Integer
			Dim iMaxRow As Integer
			sExt = pFileNm.Substring(pFileNm.LastIndexOf(CST_STR_DOT) + 1)	'拡張子を取得
			If sExt.Length = CST_BOOK_EXT_LEN_2007 Then
				iMaxCol = CST_SHT_MAX_COL_2007
				iMaxRow = CST_SHT_MAX_ROW_2007
			Else
				iMaxCol = CST_SHT_MAX_COL_2003
				iMaxRow = CST_SHT_MAX_ROW_2003
			End If
			'列数がExcel出力不可の場合はエラー
			Dim chkMaxCol As Integer
			If pbPutExcel Then
				chkMaxCol = iMaxCol - CST_DEF_HEADER_COL	'縦軸列を除く
			Else
				Dim shtCellInfo As New BaseShtCellInfo(pPrmShtData.PrintMode)
				chkMaxCol = iMaxCol - shtCellInfo.TitleTate.Col	'縦軸列を除く
			End If
			If cTate(0).LstYokoData.Count > chkMaxCol Then
				pErrMsgCd = "E0003"
				ReDim pErrMsgParm(2)
				pErrMsgParm(0) = "出力する列の数がEXCELの最大値を超過している"
				pErrMsgParm(1) = "出力"
				pErrMsgParm(2) = Nothing
				bResult = False
				Return bResult
			End If
			'行数がExcel出力不可の場合はエラー
			Dim chkMaxRow As Integer
			If pbPutExcel Then
				chkMaxRow = iMaxRow - (CST_DEF_DETAIL_START_ROW - 1)	'見出し行１行を除く
			Else
				Dim shtCellInfo As New BaseShtCellInfo(pPrmShtData.PrintMode)
				chkMaxRow = iMaxRow - (shtCellInfo.StartData.Row - 1)	'データ開始位置
			End If
			If cTate.Count > chkMaxRow Then
				pErrMsgCd = "E0003"
				ReDim pErrMsgParm(2)
				pErrMsgParm(0) = "出力する行の数がEXCELの最大値を超過している"
				pErrMsgParm(1) = "出力"
				pErrMsgParm(2) = Nothing
				bResult = False
				Return bResult
			End If
		Catch ex As Exception
			Throw
		End Try
		Return bResult
	End Function

#End Region

End Class
